#!/bin/sh
# ----------------------------------------------------------------------------
# /tmp/install.sh - freeradius installation
#
# Creation   : 2010-02-19 stm
# Last update: $Id: install.sh 513 2011-04-01 22:14:32Z stm $
#
# Copyright (c) 2010 Stephan Manske, eisfair-develop(at)stephan(dot)manske-net(dot)de
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# ----------------------------------------------------------------------------

callDir=`pwd`

# include eislib
. /var/install/include/eislib

### package definition
package='freeradius'
package_name='FreeRadius Server'
package_pos=80

mecho -info "running install.sh ..."

# ----------------------------------------------------------------------------
# Setup step 1
# ----------------------------------------------------------------------------

### install startup/stop-scripts
package_start='S'${package_pos}${package}
package_kill='K'`/usr/bin/expr 100 - $package_pos`${package}

case ${EISFAIR_SYSTEM} in
    eisfair-2)
        # eisfair-2

        ### symbolic links
        mecho "creating symbolic links for init scripts ..."

        rm -f /etc/rc[0126S].d/[KS]??$package

        ln -sf /etc/init.d/$package /etc/rc0.d/$package_kill
        ln -sf /etc/init.d/$package /etc/rc1.d/$package_kill
        ln -sf /etc/init.d/$package /etc/rc6.d/$package_kill
        ln -sf /etc/init.d/$package /etc/rcS.d/$package_kill
        ln -sf /etc/init.d/$package /etc/rc2.d/$package_start
        ;;
    *)
        # default to eisfair-1

        ### symbolic links
        mecho "creating symbolic links for init scripts ..."

        rm -f /etc/rc2.d/[KS]??$package

        ln -sf /etc/init.d/$package /etc/rc2.d/$package_kill
        ln -sf /etc/init.d/$package /etc/rc2.d/$package_start
        ;;
esac

# ----------------------------------------------------------------------------
# Setup step 2 - add empty folders and SymLinks
# ----------------------------------------------------------------------------

# make empty folders
mecho "creating additional folders  ..."

mkdir -p /etc/raddb/sites-enabled
mkdir -p /etc/raddb/certs/crl
mkdir -p /etc/raddb/certs/archive
mkdir -p /var/run/radiusd
mkdir -p /var/log/radius/radacct


# creating symbolic links
mecho "creating symbolic links  ..."

cd /etc/raddb/sites-enabled

ln -s ../sites-available/default           default
ln -s ../sites-available/inner-tunnel      inner-tunnel
ln -s ../sites-available/control-socket    control-socket

cd /usr/lib

ln -s rlm_chap-2.1.10.so rlm_chap.so
ln -s libfreeradius-radius-2.1.10.so libfreeradius-radius.so
ln -s rlm_acctlog-2.1.10.so rlm_acctlog.so
ln -s rlm_acct_unique-2.1.10.so rlm_acct_unique.so
ln -s rlm_always-2.1.10.so rlm_always.so
ln -s rlm_attr_filter-2.1.10.so rlm_attr_filter.so
ln -s rlm_attr_rewrite-2.1.10.so rlm_attr_rewrite.so
ln -s rlm_eap-2.1.10.so rlm_eap.so
ln -s rlm_checkval-2.1.10.so rlm_checkval.so
ln -s rlm_copy_packet-2.1.10.so rlm_copy_packet.so
ln -s rlm_detail-2.1.10.so rlm_detail.so
ln -s rlm_digest-2.1.10.so rlm_digest.so
ln -s libfreeradius-eap-2.1.10.so libfreeradius-eap.so
ln -s rlm_eap_gtc-2.1.10.so rlm_eap_gtc.so
ln -s rlm_eap_leap-2.1.10.so rlm_eap_leap.so
ln -s rlm_eap_md5-2.1.10.so rlm_eap_md5.so
ln -s rlm_eap_mschapv2-2.1.10.so rlm_eap_mschapv2.so
ln -s rlm_eap_tls-2.1.10.so rlm_eap_tls.so
ln -s rlm_eap_peap-2.1.10.so rlm_eap_peap.so
ln -s rlm_eap_sim-2.1.10.so rlm_eap_sim.so
ln -s rlm_eap_ttls-2.1.10.so rlm_eap_ttls.so
ln -s rlm_exec-2.1.10.so rlm_exec.so
ln -s rlm_expr-2.1.10.so rlm_expr.so
ln -s rlm_expiration-2.1.10.so rlm_expiration.so
ln -s rlm_files-2.1.10.so rlm_files.so
ln -s rlm_fastusers-2.1.10.so rlm_fastusers.so
ln -s rlm_otp-2.1.10.so rlm_otp.so
ln -s rlm_linelog-2.1.10.so rlm_linelog.so
ln -s rlm_logintime-2.1.10.so rlm_logintime.so
ln -s rlm_mschap-2.1.10.so rlm_mschap.so
ln -s rlm_pap-2.1.10.so rlm_pap.so
ln -s rlm_realm-2.1.10.so rlm_realm.so
ln -s rlm_passwd-2.1.10.so rlm_passwd.so
ln -s rlm_preprocess-2.1.10.so rlm_preprocess.so
ln -s rlm_radutmp-2.1.10.so rlm_radutmp.so
ln -s rlm_sql-2.1.10.so rlm_sql.so
ln -s rlm_unix-2.1.10.so rlm_unix.so
ln -s rlm_sqlcounter-2.1.10.so rlm_sqlcounter.so
ln -s rlm_sqlippool-2.1.10.so rlm_sqlippool.so
ln -s rlm_sql_log-2.1.10.so rlm_sql_log.so
ln -s rlm_policy-2.1.10.so rlm_policy.so
ln -s rlm_dynamic_clients-2.1.10.so rlm_dynamic_clients.so

# ----------------------------------------------------------------------------
# Setup step 3 - restore old ca.cnf and server.cnf and delete unneeded client.cnf
# ----------------------------------------------------------------------------

if [ -f "/etc/raddb/certs/ca.cnf.old-install" ]
then

rm /etc/raddb/certs/ca.cnf
rm /etc/raddb/certs/server.cnf

mv /etc/raddb/certs/ca.cnf.old-install /etc/raddb/certs/ca.cnf
mv /etc/raddb/certs/server.cnf.old-install /etc/raddb/certs/server.cnf

fi

rm /etc/raddb/certs/client.cnf


# ----------------------------------------------------------------------------
# Add menu
# ----------------------------------------------------------------------------

mecho "add menu item ..."

/var/install/bin/add-menu setup.services.menu \
                          setup.services.${package}.menu \
                          "${package_name}"

# ----------------------------------------------------------------------------
# update services
# ----------------------------------------------------------------------------

mecho "update services info ..."

/var/install/bin/update-services ${package}


# ----------------------------------------------------------------------------
# Create default config
# ----------------------------------------------------------------------------

### install configuration
if [ -f "/etc/config.d/${package}" ]
then
    mecho -info -n "Updating configuration ."
else
    mecho -info -n "Creating configuration ."
fi

#/var/install/config.d/${package}-update.sh

/var/install/config.d/${package}-update.sh &
while [ -n "`ps --no-headers $!`" ]
do
    mecho -info -n "."
sleep 1
done
echo


# ----------------------------------------------------------------------------
# Start configuration editor if necessary
# ----------------------------------------------------------------------------

### edit configuration
/var/install/bin/ask "Do you want to edit the configuration now" "yes" >/tmp/ask.$$
rc=${?}
a=`cat /tmp/ask.$$`
rm -f /tmp/ask.$$

# if ask break, ask returned 255
if [ ${rc} = 255 ]
then
    a=no
fi

case "${a}" in
    yes)
        /var/install/bin/edit -apply ${package} "Edit ${package_name} configuration"
    ;;
    *)
        # convert package to PACKAGES_NAME
        packages_name_upper="`echo ${package} | tr [:lower:] [:upper:] | tr '-' '_'`"

        # when no edit, set start parameter to 'no'
        mecho -warn "The configuration hasn't been edited. For security reasons the package will be disabled now. Please edit the configuration in the future."
        sed "s/^\(START_${packages_name_upper}\)=.*/\1='no'/" /etc/config.d/${package} >/tmp/CONFIG_FILE_TMP
        cp /tmp/CONFIG_FILE_TMP /etc/config.d/${package}
        rm -f /tmp/CONFIG_FILE_TMP
    ;;
esac

anykey

cd ${callDir}


exit 0
# ----------------------------------------------------------------------------
# End
# ----------------------------------------------------------------------------

